@@ -23,7 +23,7 @@ pub struct InvalidateCtx<'info> {
     recipient_token_account: Box<Account<'info, TokenAccount>>,
 
     // invalidator
-    #[account(constraint = token_manager.invalidators.contains(&invalidator.key()) @ ErrorCode::InvalidInvalidator)]
+    #[account(constraint = token_manager.invalidators.contains(&invalidator.key()) || recipient_token_account.owner == invalidator.key() @ ErrorCode::InvalidInvalidator)]
     invalidator: Signer<'info>,
     /// CHECK: This is not dangerous because we don't read or write from this account
     #[account(mut)]
